Modifique o checkpoint de consumo de dados de um shard para um consumer group.
Sintaxe da solicitação
aliyunlog log update_check_point --project=<value> --logstore=<value> --consumer_group=<value> --shard=<value> --check_point=<value> [--consumer=<value>] [--force_success=<value>] [--access-id=<value>] [--access-key=<value>] [--sts-token=<value>] [--region-endpoint=<value>] [--client-name=<value>] [--jmes-filter=<value>] [--format-output=<value>] [--decode-output=<value>]
Parâmetros da solicitação
A tabela a seguir descreve os parâmetros obrigatórios e específicos deste comando.
Nome do parâmetro | Tipos numéricos | Obrigatório | Valor de exemplo | Descrição |
--project | String | Sim | aliyun-test-project | Nome do projeto. |
--logstore | String | Sim | logstore-a | Nome do Logstore. |
--consumer_group | String | Sim | consumer-group-1 | Nome do consumer group. |
--shard | Integer | Sim | 1 | ID do shard. |
--check_point | String | Sim | MTUyNDE1NTM3OTM3MzkwODQ5Ng== | Valor do checkpoint. |
--consumer | String | Não | consumer_1 | O consumidor. |
--force_success | Boolean | Não | true | Define se a atualização deve ser forçada.
|
Para obter mais informações sobre os parâmetros globais da interface de linha de comando (CLI), consulte Global parameters.
Exemplos
-
Exemplo de solicitação
Atualize o checkpoint do shard para um consumer group específico.
aliyunlog log update_check_point --project="aliyun-test-project" --logstore="logstore-a" --consumer_group="consumer-group-1" --shard=1 --check_point="MTUyNDE1NTM3OTM3MzkwODQ5Ng==" --consumer="consumer_1" --force_success=true -
Se o comando for bem-sucedido, nenhuma resposta será retornada.Exemplo
-
Exemplo de solicitação
Use a conta padrão para modifique o tempo limite do consumer group consumer-group-1.
aliyunlog log update_consumer_group --project="aliyun-test-project" --logstore="logstore-a" --consumer_group="consumer-group-1" --timeout="360" --in_order=true -
Se o comando for bem-sucedido, nenhuma resposta será retornada. Execute o comando a seguir para consultar o consumer group.
aliyunlog log get_check_point --project="aliyun-test-project" --logstore="logstore-a" --consumer_group="consumer-group-1" --shard=3Resposta retornada:
[ { "checkpoint": "MTUyNDE1NTM3OTM3MzkwODQ5Ng==", "consumer": "", "shard": 3, "updateTime": 1719544024896258 } ]
-
Códigos de erro
Se uma mensagem de erro for retornada, consulte UpdateCheckPoint error codes para obter mais informações.